@@ -41,10 +41,6 @@
 #include <folly/portability/Constexpr.h>
 #include <folly/portability/Malloc.h>
 
-#if __cpp_lib_span
-#include <span>
-#endif
-
 namespace folly {
 
 namespace access {
@@ -901,88 +897,4 @@ template <typename Value, typename T>
 struct AllocatorHasDefaultObjectDestroy<std::allocator<Value>, T>
     : std::true_type {};
 
-#if __cpp_lib_span
-
-namespace detail {
-
-struct span_cast_impl_fn {
-  template <typename U, typename T, std::size_t Extend>
-  constexpr auto operator()(std::span<T, Extend> in, U* castData) const {
-    assert(
-        static_cast<const void*>(in.data()) ==
-        static_cast<const void*>(castData));
-
-    // check alignment
-    if (!folly::is_constant_evaluated_or(true)) {
-      assert(reinterpret_cast<std::uintptr_t>(in.data()) % sizeof(U) == 0);
-    }
-
-    if constexpr (Extend == std::dynamic_extent) {
-      assert(in.size() * sizeof(T) % sizeof(U) == 0);
-      return std::span<U>(castData, in.size() * sizeof(T) / sizeof(U));
-    } else {
-      static_assert(in.size() * sizeof(T) % sizeof(U) == 0);
-      constexpr std::size_t kResSize = Extend * sizeof(T) / sizeof(U);
-      return std::span<U, kResSize>(castData, kResSize);
-    }
-  }
-
-} inline constexpr span_cast_impl;
-
-} // namespace detail
-
-/**
- * static_span_cast
- * static_span_cast_fn
- * reinterpret_span_cast
- * reinterpret_span_cast_fn
- * const_span_cast
- * const_span_cast_fn
- *
- * converting a span to a different span.
- * (you get a span to the same bytes but treated as different type)
- *
- * Example:
- *
- *    enum class SomeEnum : int { ... };
- *
- *    std::span<SomeEnum> s = ...
- *    std::span<int> as_ints = folly::reinterpret_span_cast<int>(s);
- */
-
-template <typename U>
-struct static_span_cast_fn {
-  template <typename T, std::size_t Extend>
-  constexpr auto operator()(std::span<T, Extend> in) const {
-    return detail::span_cast_impl(in, static_cast<U*>(in.data()));
-  }
-};
-
-template <typename U>
-inline constexpr static_span_cast_fn<U> static_span_cast;
-
-template <typename U>
-struct reinterpret_span_cast_fn {
-  template <typename T, std::size_t Extend>
-  constexpr auto operator()(std::span<T, Extend> in) const {
-    return detail::span_cast_impl(in, reinterpret_cast<U*>(in.data()));
-  }
-};
-
-template <typename U>
-inline constexpr reinterpret_span_cast_fn<U> reinterpret_span_cast;
-
-template <typename U>
-struct const_span_cast_fn {
-  template <typename T, std::size_t Extend>
-  constexpr auto operator()(std::span<T, Extend> in) const {
-    return detail::span_cast_impl(in, const_cast<U*>(in.data()));
-  }
-};
-
-template <typename U>
-inline constexpr const_span_cast_fn<U> const_span_cast;
-
-#endif
-
 } // namespace folly
