@@ -127,7 +127,7 @@ BufferedRandomDevice::BufferedRandomDevice(size_t bufferSize)
     : bufferSize_(bufferSize),
       buffer_(new unsigned char[bufferSize]),
       ptr_(buffer_.get() + bufferSize) { // refill on first use
-  FOLLY_MAYBE_UNUSED static auto const init = [] {
+  [[maybe_unused]] static auto const init = [] {
     AtFork::registerHandler(
         nullptr,
         /*prepare*/ []() { return true; },
