@@ -17,10 +17,10 @@
 #pragma once
 
 #include <folly/channels/Channel.h>
+#include <folly/coro/AsyncGenerator.h>
+#include <folly/coro/Task.h>
 #include <folly/executors/SequencedExecutor.h>
 #include <folly/experimental/channels/detail/Utility.h>
-#include <folly/experimental/coro/AsyncGenerator.h>
-#include <folly/experimental/coro/Task.h>
 
 namespace folly {
 namespace channels {
@@ -456,7 +456,7 @@ template <>
 class RateLimiterHolder<false> {
  public:
   explicit RateLimiterHolder(std::shared_ptr<RateLimiter> rateLimiter) {
-    CHECK_NULL(rateLimiter.get());
+    CHECK_EQ(rateLimiter.get(), static_cast<void*>(NULL));
   }
 
   std::shared_ptr<RateLimiter> getRateLimiter() { return nullptr; }
