@@ -18,9 +18,9 @@
 #include <folly/channels/MaxConcurrentRateLimiter.h>
 #include <folly/channels/MultiplexChannel.h>
 #include <folly/channels/test/ChannelTestUtil.h>
+#include <folly/coro/BlockingWait.h>
 #include <folly/executors/ManualExecutor.h>
 #include <folly/executors/SerialExecutor.h>
-#include <folly/experimental/coro/BlockingWait.h>
 #include <folly/portability/GMock.h>
 #include <folly/portability/GTest.h>
 
