@@ -31,9 +31,9 @@
 #include <folly/Likely.h>
 #include <folly/Portability.h>
 #include <folly/Range.h>
+#include <folly/compression/Instructions.h>
+#include <folly/compression/Select64.h>
 #include <folly/compression/elias_fano/CodingDetail.h>
-#include <folly/experimental/Instructions.h>
-#include <folly/experimental/Select64.h>
 #include <folly/lang/Assume.h>
 #include <folly/lang/Bits.h>
 
