@@ -210,6 +210,13 @@ namespace folly {
 ///   may yield better results due to, for example, more favorable
 ///   producer-consumer balance or favorable timing for avoiding
 ///   costly blocking.
+///
+/// Guarantees:
+/// - The queues are linearizable:
+///   - For two enqueue operations q(A) and q(B), if q(A) < q(B) in
+///     the happens-before relation, then A precedes B in the queue.
+///   - For two dequeue operations d(A) and d(B), if d(A) < d(B) in
+///     the happens-before relation, then A preceded B in the queue.
 
 template <
     typename T,
@@ -255,6 +262,9 @@ class UnboundedQueue {
   alignas(Align) Producer p_;
 
  public:
+  using value_type = T;
+  using size_type = size_t;
+
   /** constructor */
   UnboundedQueue()
       : c_(new Segment(0)), p_(c_.head.load(std::memory_order_relaxed)) {}
@@ -278,7 +288,7 @@ class UnboundedQueue {
   /** try_dequeue */
   FOLLY_ALWAYS_INLINE bool try_dequeue(T& item) noexcept {
     auto o = try_dequeue();
-    if (LIKELY(o.has_value())) {
+    if (FOLLY_LIKELY(o.has_value())) {
       item = std::move(*o);
       return true;
     }
@@ -296,7 +306,7 @@ class UnboundedQueue {
       const std::chrono::time_point<Clock, Duration>& deadline) noexcept {
     folly::Optional<T> o = try_dequeue_until(deadline);
 
-    if (LIKELY(o.has_value())) {
+    if (FOLLY_LIKELY(o.has_value())) {
       item = std::move(*o);
       return true;
     }
@@ -316,7 +326,7 @@ class UnboundedQueue {
       T& item, const std::chrono::duration<Rep, Period>& duration) noexcept {
     folly::Optional<T> o = try_dequeue_for(duration);
 
-    if (LIKELY(o.has_value())) {
+    if (FOLLY_LIKELY(o.has_value())) {
       item = std::move(*o);
       return true;
     }
@@ -328,7 +338,7 @@ class UnboundedQueue {
   FOLLY_ALWAYS_INLINE folly::Optional<T> try_dequeue_for(
       const std::chrono::duration<Rep, Period>& duration) noexcept {
     folly::Optional<T> o = try_dequeue();
-    if (LIKELY(o.has_value())) {
+    if (FOLLY_LIKELY(o.has_value())) {
       return o;
     }
     return tryDequeueUntil(std::chrono::steady_clock::now() + duration);
@@ -446,7 +456,7 @@ class UnboundedQueue {
     DCHECK_LT(t, (s->minTicket() + SegmentSize));
     size_t idx = index(t);
     Entry& e = s->entry(idx);
-    if (UNLIKELY(!tryDequeueWaitElem(e, t, deadline))) {
+    if (FOLLY_UNLIKELY(!tryDequeueWaitElem(e, t, deadline))) {
       return folly::Optional<T>();
     }
     setConsumerTicket(t + 1);
@@ -464,14 +474,14 @@ class UnboundedQueue {
       const std::chrono::time_point<Clock, Duration>& deadline) noexcept {
     while (true) {
       Ticket t = consumerTicket();
-      if (UNLIKELY(t >= (s->minTicket() + SegmentSize))) {
+      if (FOLLY_UNLIKELY(t >= (s->minTicket() + SegmentSize))) {
         s = getAllocNextSegment(s, t);
         DCHECK(s);
         continue;
       }
       size_t idx = index(t);
       Entry& e = s->entry(idx);
-      if (UNLIKELY(!tryDequeueWaitElem(e, t, deadline))) {
+      if (FOLLY_UNLIKELY(!tryDequeueWaitElem(e, t, deadline))) {
         return folly::Optional<T>();
       }
       if (!c_.ticket.compare_exchange_weak(
@@ -492,7 +502,7 @@ class UnboundedQueue {
       Entry& e,
       Ticket t,
       const std::chrono::time_point<Clock, Duration>& deadline) noexcept {
-    if (LIKELY(e.tryWaitUntil(deadline))) {
+    if (FOLLY_LIKELY(e.tryWaitUntil(deadline))) {
       return true;
     }
     return t < producerTicket();
@@ -510,7 +520,7 @@ class UnboundedQueue {
     DCHECK_LT(t, (s->minTicket() + SegmentSize));
     size_t idx = index(t);
     Entry& e = s->entry(idx);
-    if (UNLIKELY(!tryDequeueWaitElem(e, t, deadline))) {
+    if (FOLLY_UNLIKELY(!tryDequeueWaitElem(e, t, deadline))) {
       return nullptr;
     }
     return e.peekItem();
@@ -519,7 +529,7 @@ class UnboundedQueue {
   /** findSegment */
   FOLLY_ALWAYS_INLINE
   Segment* findSegment(Segment* s, const Ticket t) noexcept {
-    while (UNLIKELY(t >= (s->minTicket() + SegmentSize))) {
+    while (FOLLY_UNLIKELY(t >= (s->minTicket() + SegmentSize))) {
       s = getAllocNextSegment(s, t);
       DCHECK(s);
     }
