@@ -693,7 +693,6 @@ struct value_compare_set : Compare {
  * @tparam KeyT            key type, for set it is same as T.
  * @tparam ValueCompare    wrapper class to compare Container::value_type
  *
- * @author Zino Benaissa <zinob@fb.com>
  */
 template <
     class T,
@@ -1269,8 +1268,8 @@ class heap_vector_container : growth_policy_wrapper<GrowthPolicy> {
   }
 
   void swap(heap_vector_container& o) noexcept(
-      std::is_nothrow_swappable<Compare>::value&& noexcept(
-          std::declval<Container&>().swap(std::declval<Container&>()))) {
+      std::is_nothrow_swappable<Compare>::value &&
+      noexcept(std::declval<Container&>().swap(std::declval<Container&>()))) {
     using std::swap; // Allow ADL for swap(); fall back to std::swap().
     Compare& a = m_;
     Compare& b = o.m_;
@@ -1319,22 +1318,22 @@ class heap_vector_container : growth_policy_wrapper<GrowthPolicy> {
     explicit EBO(const value_compare& c, const Allocator& alloc) noexcept(
         std::is_nothrow_default_constructible<Container>::value)
         : value_compare(c), cont_(alloc) {}
-    EBO(const EBO& other, const Allocator& alloc)
-    noexcept(std::is_nothrow_constructible<
-             Container,
-             const Container&,
-             const Allocator&>::value)
+    EBO(const EBO& other, const Allocator& alloc) noexcept(
+        std::is_nothrow_constructible<
+            Container,
+            const Container&,
+            const Allocator&>::value)
         : value_compare(static_cast<const value_compare&>(other)),
           cont_(other.cont_, alloc) {}
-    EBO(EBO&& other, const Allocator& alloc)
-    noexcept(std::is_nothrow_constructible<
-             Container,
-             Container&&,
-             const Allocator&>::value)
+    EBO(EBO&& other, const Allocator& alloc) noexcept(
+        std::is_nothrow_constructible<
+            Container,
+            Container&&,
+            const Allocator&>::value)
         : value_compare(static_cast<value_compare&&>(other)),
           cont_(std::move(other.cont_), alloc) {}
-    EBO(const Compare& c, Container&& cont)
-    noexcept(std::is_nothrow_move_constructible<Container>::value)
+    EBO(const Compare& c, Container&& cont) noexcept(
+        std::is_nothrow_move_constructible<Container>::value)
         : value_compare(c), cont_(std::move(cont)) {}
     Container cont_;
   } m_;
@@ -1459,7 +1458,6 @@ using heap_vector_set = folly::heap_vector_set<
  * @tparam Allocator     allocation policy
  * @tparam GrowthPolicy  policy object to control growth
  *
- * @author Zino Benaissa <zinob@fb.com>
  */
 
 template <
@@ -1591,7 +1589,8 @@ template <
         std::pair<Key, Value>,
         0,
         folly::small_vector_policy::policy_size_type<SizeType>>,
-    typename = std::enable_if_t<std::is_integral<Key>::value>>
+    typename = std::enable_if_t<
+        std::is_integral<Key>::value || std::is_enum<Key>::value>>
 class small_heap_vector_map : public folly::heap_vector_map<
                                   Key,
                                   Value,
