@@ -31,13 +31,13 @@
 #include <type_traits>
 #include <vector>
 
-#if __has_include(<ranges>)
+#if defined(__cpp_lib_ranges)
 #include <ranges>
 #endif
 
 namespace folly {
 
-#if __has_include(<ranges>)
+#if defined(__cpp_lib_ranges)
 #define FOLLY_TAPE_CONTAINER_REQUIRES std::ranges::random_access_range
 #else
 #define FOLLY_TAPE_CONTAINER_REQUIRES typename
@@ -64,7 +64,8 @@ namespace folly {
  * `record_builder` interface.
  *
  * Existing `records` can be accessed by index.
- * Existing `records` cannot be mutated.
+ * Existing `records` cannot be mutated, except for the last record (see record
+ * builder).
  *
  * ## tape<tape>
  *
@@ -230,9 +231,10 @@ class tape {
   }
 
   template <typename R>
-  auto push_back(R&& r) -> std::enable_if_t<
-      range_of_scalars<R> &&
-      !std::is_convertible_v<R, const_reference>> // handle \0 separately
+  auto push_back(R&& r)
+      -> std::enable_if_t<
+          range_of_scalars<R> &&
+          !std::is_convertible_v<R, const_reference>> // handle \0 separately
   {
     push_back(std::begin(r), std::end(r));
   }
@@ -263,9 +265,10 @@ class tape {
   }
 
   template <typename R>
-  auto push_back_unsafe(R&& r) -> std::enable_if_t<
-      range_of_scalars<R> &&
-      !std::is_convertible_v<R, const_reference>> // handle \0 separately
+  auto push_back_unsafe(R&& r)
+      -> std::enable_if_t<
+          range_of_scalars<R> &&
+          !std::is_convertible_v<R, const_reference>> // handle \0 separately
   {
     push_back_unsafe(std::begin(r), std::end(r));
   }
@@ -276,8 +279,13 @@ class tape {
 
   // record builder (constructing last record) -------
 
-  class scoped_record_builder;
-  [[nodiscard]] scoped_record_builder record_builder();
+  class record_builder;
+
+  // get a record builder.
+  // new_record_builder starts a builder for a new record.
+  // last_record_builder allows you to append/mutate the last record.
+  [[nodiscard]] record_builder new_record_builder();
+  [[nodiscard]] record_builder last_record_builder();
 
   // insert one record ----------
 
@@ -286,9 +294,10 @@ class tape {
       -> std::enable_if_t<iterator_of_scalars<I>, iterator>;
 
   template <typename R>
-  auto insert(const_iterator pos, R&& r) -> std::enable_if_t<
-      range_of_scalars<R> && !std::is_convertible_v<R, const_reference>,
-      iterator> {
+  auto insert(const_iterator pos, R&& r)
+      -> std::enable_if_t<
+          range_of_scalars<R> && !std::is_convertible_v<R, const_reference>,
+          iterator> {
     return insert(pos, std::begin(r), std::end(r));
   }
 
@@ -328,6 +337,7 @@ class tape {
   // erase -------
 
   void pop_back() noexcept {
+    assert(!empty());
     data_.resize(data_.size() - back().size());
     markers_.pop_back();
   }
@@ -356,6 +366,11 @@ class tape {
   friend bool operator<=(const tape& x, const tape& y) { return !(y < x); }
   friend bool operator>=(const tape& x, const tape& y) { return !(x < y); }
 
+  folly::Range<const difference_type*> markers() const { return markers_; }
+  reference scalars() const {
+    return ref_traits::make(data_.begin(), data_.end());
+  }
+
  private:
   template <typename I, typename S>
   void range_constructor(I f, S l);
@@ -369,13 +384,15 @@ class tape {
 
 // Provides a way to construct a last record similar
 // to how you would `std::vector`.
+// Typical workflow is you `push_back` a bunch of individual elements and then
+// `commit()`.
 template <FOLLY_TAPE_CONTAINER_REQUIRES Container>
-class tape<Container>::scoped_record_builder {
+class tape<Container>::record_builder {
  public:
-  scoped_record_builder(const scoped_record_builder&) = delete;
-  scoped_record_builder(scoped_record_builder&&) = delete;
-  scoped_record_builder& operator=(const scoped_record_builder&) = delete;
-  scoped_record_builder& operator=(scoped_record_builder&&) = delete;
+  record_builder(const record_builder&) = delete;
+  record_builder(record_builder&&) = delete;
+  record_builder& operator=(const record_builder&) = delete;
+  record_builder& operator=(record_builder&&) = delete;
 
   using iterator = typename container_type::iterator;
   using const_iterator = typename container_type::const_iterator;
@@ -386,6 +403,23 @@ class tape<Container>::scoped_record_builder {
   using difference_type =
       typename std::iterator_traits<iterator>::difference_type;
 
+  // mutators ---
+
+  void push_back(scalar_value_type x) { self_->data_.push_back(std::move(x)); }
+
+  template <typename... Args>
+  reference emplace_back(Args&&... args) {
+    self_->data_.emplace_back(std::forward<Args>(args)...);
+    // cannot rely on the container doing the right thing here.
+    return self_->data_.back();
+  }
+
+  // constructed record is added to the tape.
+  void commit() { self_->markers_.push_back(self_->data_.size()); }
+
+  // discards elements of the constructed record. (automatic on destruction)
+  void abort() { self_->data_.resize(self_->markers_.back()); }
+
   // iterators -----
 
   [[nodiscard]] iterator begin() noexcept {
@@ -443,33 +477,26 @@ class tape<Container>::scoped_record_builder {
   [[nodiscard]] reference back() { return self_->data_.back(); }
   [[nodiscard]] const_reference back() const { return self_->data_.back(); }
 
-  // mutators ---
-
-  void push_back(scalar_value_type x) { self_->data_.push_back(std::move(x)); }
-
-  template <typename... Args>
-  reference emplace_back(Args&&... args) {
-    self_->data_.emplace_back(std::forward<Args>(args)...);
-    // cannot rely on the container doing the right thing here.
-    return self_->data_.back();
-  }
-
-  ~scoped_record_builder() noexcept {
-    // we assume that allocations never fail
-    self_->markers_.push_back(self_->data_.size());
-  }
+  ~record_builder() noexcept { abort(); }
 
  private:
   friend class tape;
 
-  explicit scoped_record_builder(tape& self) : self_(&self) {}
+  explicit record_builder(tape& self) : self_(&self) {}
 
   tape* self_;
 };
 
 template <FOLLY_TAPE_CONTAINER_REQUIRES Container>
-auto tape<Container>::record_builder() -> scoped_record_builder {
-  return scoped_record_builder{*this};
+auto tape<Container>::new_record_builder() -> record_builder {
+  return record_builder{*this};
+}
+
+template <FOLLY_TAPE_CONTAINER_REQUIRES Container>
+auto tape<Container>::last_record_builder() -> record_builder {
+  assert(!empty());
+  markers_.pop_back();
+  return new_record_builder();
 }
 
 // tape methods -----
