@@ -65,7 +65,8 @@ namespace folly {
  * priority tasks could still hog all the threads. (at last check pthreads
  * thread priorities didn't work very well).
  */
-class CPUThreadPoolExecutor : public ThreadPoolExecutor {
+class CPUThreadPoolExecutor : public ThreadPoolExecutor,
+                              public GetThreadIdCollector {
  public:
   struct CPUTask;
   struct Options {
@@ -76,7 +77,7 @@ class CPUThreadPoolExecutor : public ThreadPoolExecutor {
 
     constexpr Options() noexcept : blocking{Blocking::allow} {}
 
-    Options setBlocking(Blocking b) {
+    Options& setBlocking(Blocking b) {
       blocking = b;
       return *this;
     }
@@ -84,12 +85,16 @@ class CPUThreadPoolExecutor : public ThreadPoolExecutor {
     Blocking blocking;
   };
 
-  // These function return unbounded blocking queues with the default semaphore
-  // (LifoSem).
+  // These function return unbounded blocking queues with the default semaphore.
   static std::unique_ptr<BlockingQueue<CPUTask>> makeDefaultQueue();
   static std::unique_ptr<BlockingQueue<CPUTask>> makeDefaultPriorityQueue(
       int8_t numPriorities);
 
+  // These function return unbounded blocking queues with LifoSem.
+  static std::unique_ptr<BlockingQueue<CPUTask>> makeLifoSemQueue();
+  static std::unique_ptr<BlockingQueue<CPUTask>> makeLifoSemPriorityQueue(
+      int8_t numPriorities);
+
   // These function return unbounded blocking queues with ThrottledLifoSem.
   static std::unique_ptr<BlockingQueue<CPUTask>> makeThrottledLifoSemQueue(
       std::chrono::nanoseconds wakeUpInterval = {});
@@ -158,34 +163,27 @@ class CPUThreadPoolExecutor : public ThreadPoolExecutor {
 
   uint8_t getNumPriorities() const override;
 
+  /// Implements the GetThreadIdCollector interface
+  WorkerProvider* FOLLY_NULLABLE getThreadIdCollector() override;
+
   struct CPUTask : public ThreadPoolExecutor::Task {
+    CPUTask(); // Poison.
     CPUTask(
         Func&& f,
         std::chrono::milliseconds expiration,
         Func&& expireCallback,
-        int8_t pri)
-        : Task(std::move(f), expiration, std::move(expireCallback)),
-          priority_(pri) {}
-    CPUTask()
-        : Task(nullptr, std::chrono::milliseconds(0), nullptr),
-          poison(true),
-          priority_(0) {}
-
-    size_t queuePriority() const { return priority_; }
-
-    intptr_t& queueObserverPayload() { return queueObserverPayload_; }
-
-    bool poison = false;
+        int8_t pri);
 
    private:
-    int8_t priority_;
+    friend class CPUThreadPoolExecutor;
+
     intptr_t queueObserverPayload_;
   };
 
   static const size_t kDefaultMaxQueueSize;
 
  protected:
-  BlockingQueue<CPUTask>* getTaskQueue();
+  BlockingQueue<CPUTask>* FOLLY_NONNULL getTaskQueue();
   std::unique_ptr<ThreadIdWorkerProvider> threadIdCollector_{
       std::make_unique<ThreadIdWorkerProvider>()};
 
