@@ -18,6 +18,7 @@
 
 #include <atomic>
 #include <cstddef>
+#include <limits>
 #include <memory>
 #include <vector>
 
@@ -62,8 +63,8 @@ class EDFThreadPoolExecutor : public SoftRealTimeExecutor,
   static constexpr uint64_t kLatestDeadline =
       std::numeric_limits<uint64_t>::max();
 
-  // Default semaphore is LifoSem.
   static std::unique_ptr<EDFThreadPoolSemaphore> makeDefaultSemaphore();
+  static std::unique_ptr<EDFThreadPoolSemaphore> makeLifoSemSemaphore();
   static std::unique_ptr<EDFThreadPoolSemaphore> makeThrottledLifoSemSemaphore(
       std::chrono::nanoseconds wakeUpInterval = {});
 
@@ -83,7 +84,7 @@ class EDFThreadPoolExecutor : public SoftRealTimeExecutor,
   void add(Func f, std::size_t total, uint64_t deadline) override;
   void add(std::vector<Func> fs, uint64_t deadline) override;
 
-  folly::Executor::KeepAlive<> deadlineExecutor(uint64_t deadline);
+  size_t getTaskQueueSize() const;
 
  protected:
   void threadRun(ThreadPtr thread) override;
@@ -94,6 +95,9 @@ class EDFThreadPoolExecutor : public SoftRealTimeExecutor,
   bool shouldStop();
   std::shared_ptr<Task> take();
 
+  void fillTaskInfo(const Task& task, TaskInfo& info);
+  void registerTaskEnqueue(const Task& task);
+
   std::unique_ptr<TaskQueue> taskQueue_;
   std::unique_ptr<EDFThreadPoolSemaphore> sem_;
   std::atomic<int> threadsToStop_{0};
