@@ -36,7 +36,7 @@
 #include <folly/io/async/HHWheelTimer.h>
 #include <folly/io/async/Request.h>
 
-#include <folly/experimental/ExecutionObserver.h>
+#include <folly/executors/ExecutionObserver.h>
 #include <folly/fibers/BoostContextCompatibility.h>
 #include <folly/fibers/Fiber.h>
 #include <folly/fibers/GuardPageAllocator.h>
