@@ -580,8 +580,7 @@ makeSemiFutureWith(F&& func) {
   try {
     return static_cast<F&&>(func)();
   } catch (...) {
-    return makeSemiFuture<InnerType>(
-        exception_wrapper(std::current_exception()));
+    return makeSemiFuture<InnerType>(exception_wrapper(current_exception()));
   }
 }
 
@@ -855,7 +854,7 @@ SemiFuture<T> SemiFuture<T>::deferEnsure(F&& func) && {
 
 template <class T>
 SemiFuture<Unit> SemiFuture<T>::unit() && {
-  return std::move(*this).deferValue([](T&&) {});
+  return std::move(*this).deferValue(variadic_noop);
 }
 
 template <typename T>
@@ -1274,7 +1273,7 @@ Future<T>::thenErrorImpl(
 
 template <class T>
 Future<Unit> Future<T>::then() && {
-  return std::move(*this).thenValue([](T&&) {});
+  return std::move(*this).thenValue(variadic_noop);
 }
 
 template <class T>
@@ -1338,7 +1337,7 @@ typename std::
   try {
     return static_cast<F&&>(func)();
   } catch (...) {
-    return makeFuture<InnerType>(exception_wrapper(std::current_exception()));
+    return makeFuture<InnerType>(exception_wrapper(current_exception()));
   }
 }
 
@@ -2054,7 +2053,7 @@ SemiFuture<T> unorderedReduceSemiFuture(It first, It last, T initial, F func) {
                     std::move(v.value()),
                     mt.template get<IsTry::value, Arg&&>()));
           } catch (...) {
-            ew = exception_wrapper{std::current_exception()};
+            ew = exception_wrapper{current_exception()};
           }
           if (ew) {
             mp.setException(std::move(ew));
@@ -2105,6 +2104,34 @@ Future<T> Future<T>::within(HighResDuration dur, E e, Timekeeper* tk) && {
   return std::move(*this).semi().within(dur, e, tk).via(std::move(exe));
 }
 
+namespace futures {
+namespace detail {
+
+struct WithinInterruptHandler {
+  std::weak_ptr<CoreBase> ptr;
+  void operator()(exception_wrapper const& ew) const;
+};
+
+struct WithinContextBase {
+  using PromiseSetExceptionSig = void(WithinContextBase&, exception_wrapper&&);
+  PromiseSetExceptionSig* doPromiseSetException{};
+  exception_wrapper exception;
+  SemiFuture<Unit> thisFuture{SemiFuture<Unit>::makeEmpty()};
+  SemiFuture<Unit> afterFuture{SemiFuture<Unit>::makeEmpty()};
+  std::atomic<bool> token{false};
+  explicit WithinContextBase(
+      PromiseSetExceptionSig* fun, exception_wrapper&& e) noexcept
+      : doPromiseSetException{fun}, exception{std::move(e)} {}
+};
+
+struct WithinAfterFutureCallback {
+  std::weak_ptr<WithinContextBase> ctx;
+  void operator()(Try<Unit>&& t);
+};
+
+} // namespace detail
+} // namespace futures
+
 template <class T>
 template <typename E>
 SemiFuture<T> SemiFuture<T>::within(
@@ -2113,13 +2140,16 @@ SemiFuture<T> SemiFuture<T>::within(
     return std::move(*this);
   }
 
-  struct Context {
-    explicit Context(E ex) : exception(std::move(ex)) {}
-    E exception;
-    SemiFuture<Unit> thisFuture{SemiFuture<Unit>::makeEmpty()};
-    SemiFuture<Unit> afterFuture{SemiFuture<Unit>::makeEmpty()};
+  using ContextBase = futures::detail::WithinContextBase;
+  struct Context : ContextBase {
+    static void goPromiseSetException(
+        ContextBase& base, exception_wrapper&& e) {
+      static_cast<Context&>(base).promise.setException(std::move(e));
+    }
     Promise<T> promise;
-    std::atomic<bool> token{false};
+    explicit Context(E ex)
+        : ContextBase(goPromiseSetException, exception_wrapper(std::move(ex))) {
+    }
   };
 
   std::shared_ptr<Timekeeper> tks;
@@ -2144,36 +2174,11 @@ SemiFuture<T> SemiFuture<T>::within(
   // Have time keeper use a weak ptr to hold ctx,
   // so that ctx can be deallocated as soon as the future job finished.
   ctx->afterFuture =
-      tk->after(dur).defer([weakCtx = to_weak_ptr(ctx)](Try<Unit>&& t) mutable {
-        if (t.hasException() &&
-            t.exception().is_compatible_with<FutureCancellation>()) {
-          // This got cancelled by thisFuture so we can just return.
-          return;
-        }
-
-        auto lockedCtx = weakCtx.lock();
-        if (!lockedCtx) {
-          // ctx already released. "this" completed first, cancel "after"
-          return;
-        }
-        // "after" completed first, cancel "this"
-        lockedCtx->thisFuture.raise(FutureTimeout());
-        if (!lockedCtx->token.exchange(true, std::memory_order_relaxed)) {
-          if (t.hasException()) {
-            lockedCtx->promise.setException(std::move(t.exception()));
-          } else {
-            lockedCtx->promise.setException(std::move(lockedCtx->exception));
-          }
-        }
-      });
+      tk->after(dur).defer(futures::detail::WithinAfterFutureCallback{ctx});
 
   // Properly propagate interrupt values through futures chained after within()
-  ctx->promise.setInterruptHandler(
-      [weakCtx = to_weak_ptr(ctx)](const exception_wrapper& ex) {
-        if (auto lockedCtx = weakCtx.lock()) {
-          lockedCtx->thisFuture.raise(ex);
-        }
-      });
+  ctx->promise.setInterruptHandler(futures::detail::WithinInterruptHandler{
+      to_weak_ptr_aliasing(ctx, ctx->thisFuture.core_)});
 
   // Construct the future to return, create a fresh DeferredExecutor and
   // nest the other two inside it, in case they already carry nested executors.
@@ -2186,8 +2191,8 @@ SemiFuture<T> SemiFuture<T>::within(
   nestedExecutors.emplace_back(ctx->thisFuture.stealDeferredExecutor());
   nestedExecutors.emplace_back(ctx->afterFuture.stealDeferredExecutor());
   // Set trivial callbacks to treat the futures as consumed
-  ctx->thisFuture.setCallback_([](Executor::KeepAlive<>&&, Try<Unit>&&) {});
-  ctx->afterFuture.setCallback_([](Executor::KeepAlive<>&&, Try<Unit>&&) {});
+  ctx->thisFuture.setCallback_(variadic_noop);
+  ctx->afterFuture.setCallback_(variadic_noop);
   futures::detail::getDeferredExecutor(fut)->setNestedExecutors(
       std::move(nestedExecutors));
   return fut;
