@@ -23,13 +23,12 @@
 #include <exception>
 #include <functional>
 #include <memory>
+#include <variant>
 #include <vector>
-#include <boost/variant.hpp>
 
 #include <folly/ExceptionWrapper.h>
 #include <folly/SocketAddress.h>
 #include <folly/String.h>
-#include <folly/experimental/observer/Observer.h>
 #include <folly/io/ShutdownSocketSet.h>
 #include <folly/io/async/AsyncSocketBase.h>
 #include <folly/io/async/AsyncTimeout.h>
@@ -39,6 +38,7 @@
 #include <folly/io/async/EventHandler.h>
 #include <folly/net/NetOps.h>
 #include <folly/net/NetworkSocket.h>
+#include <folly/observer/Observer.h>
 #include <folly/portability/Sockets.h>
 
 // Due to the way kernel headers are included, this may or may not be defined.
@@ -823,6 +823,12 @@ class AsyncServerSocket : public DelayedDestruction, public AsyncSocketBase {
     return connectionEventCallback_;
   }
 
+  /**
+   * Index of the callback with the same EVB as the current
+   * AsyncServerSocket instance, if any
+   */
+  int getLocalCallbackIndex() const { return localCallbackIndex_; }
+
  protected:
   /**
    * Protected destructor.
@@ -857,7 +863,7 @@ class AsyncServerSocket : public DelayedDestruction, public AsyncSocketBase {
         RemoteAcceptor& acceptor) noexcept;
   };
 
-  using QueueMessage = boost::variant<NewConnMessage, ErrorMessage>;
+  using QueueMessage = std::variant<NewConnMessage, ErrorMessage>;
 
   /**
    * A class to receive notifications to invoke AcceptCallback objects
@@ -872,7 +878,7 @@ class AsyncServerSocket : public DelayedDestruction, public AsyncSocketBase {
     struct Consumer {
       AtomicNotificationQueueTaskStatus operator()(
           QueueMessage&& msg) noexcept {
-        return boost::apply_visitor(
+        return std::visit(
             [this](auto&& visitMsg) { return visitMsg(acceptor_); }, msg);
       }
 
@@ -1011,6 +1017,7 @@ class AsyncServerSocket : public DelayedDestruction, public AsyncSocketBase {
   BackoffTimeout* backoffTimeout_;
   std::vector<CallbackInfo> callbacks_;
   CallbackAssignFunction callbackAssignFunc_;
+  int localCallbackIndex_{-1};
   bool keepAliveEnabled_;
   bool reusePortEnabled_{false};
   // SO_REUSEADDR is enabled by default
