@@ -138,13 +138,12 @@ class AsyncUDPSocket : public EventHandler {
   };
 
   static void fromMsg(
-      FOLLY_MAYBE_UNUSED ReadCallback::OnDataAvailableParams& params,
-      FOLLY_MAYBE_UNUSED struct msghdr& msg);
+      [[maybe_unused]] ReadCallback::OnDataAvailableParams& params,
+      [[maybe_unused]] struct msghdr& msg);
 
   using IOBufFreeFunc = folly::Function<void(std::unique_ptr<folly::IOBuf>&&)>;
 
-  using AdditionalCmsgsFunc =
-      folly::Function<folly::Optional<SocketOptionMap>()>;
+  using AdditionalCmsgsFunc = folly::Function<folly::Optional<SocketCmsgMap>()>;
 
   struct WriteOptions {
     WriteOptions() = default;
@@ -239,13 +238,13 @@ class AsyncUDPSocket : public EventHandler {
   /**
    * Set extra control messages to send
    */
-  virtual void setCmsgs(const SocketOptionMap& cmsgs);
+  virtual void setCmsgs(const SocketCmsgMap& cmsgs);
   virtual void setNontrivialCmsgs(
-      const SocketNontrivialOptionMap& nontrivialCmsgs);
+      const SocketNontrivialCmsgMap& nontrivialCmsgs);
 
-  virtual void appendCmsgs(const SocketOptionMap& cmsgs);
+  virtual void appendCmsgs(const SocketCmsgMap& cmsgs);
   virtual void appendNontrivialCmsgs(
-      const SocketNontrivialOptionMap& nontrivialCmsgs);
+      const SocketNontrivialCmsgMap& nontrivialCmsgs);
   virtual void setAdditionalCmsgsFunc(
       AdditionalCmsgsFunc&& additionalCmsgsFunc) {
     additionalCmsgsFunc_ = std::move(additionalCmsgsFunc);
@@ -283,7 +282,7 @@ class AsyncUDPSocket : public EventHandler {
   virtual ssize_t writeGSO(
       const folly::SocketAddress& address,
       const std::unique_ptr<folly::IOBuf>& buf,
-      int gso);
+      WriteOptions options);
 
   virtual ssize_t writeChain(
       const folly::SocketAddress& address,
@@ -295,7 +294,7 @@ class AsyncUDPSocket : public EventHandler {
    * ::sendmmsg.
    * bufs is an array of std::unique_ptr<folly::IOBuf>
    * of size num
-   * gso is an array with the generic segmentation offload values or nullptr
+   * options is an array of WriteOptions or nullptr
    *  Before calling writeGSO with a positive value
    *  verify GSO is supported on this platform by calling getGSO
    */
@@ -303,7 +302,7 @@ class AsyncUDPSocket : public EventHandler {
       Range<SocketAddress const*> addrs,
       const std::unique_ptr<folly::IOBuf>* bufs,
       size_t count,
-      const int* gso);
+      const WriteOptions* options);
 
   /**
    * Send data in iovec to destination. Returns the return code from sendmsg.
@@ -312,7 +311,7 @@ class AsyncUDPSocket : public EventHandler {
       const folly::SocketAddress& address,
       const struct iovec* vec,
       size_t iovec_len,
-      int gso);
+      WriteOptions options);
 
   virtual ssize_t writev(
       const folly::SocketAddress& address,
@@ -367,6 +366,13 @@ class AsyncUDPSocket : public EventHandler {
    */
   virtual void setRecvTos(bool recvTos) { recvTos_ = recvTos; }
 
+  /**
+   * Get IPV6_RECVTCLASS/IP_RECVTOS status of the socket. If true, the IPv6
+   * Traffic Class/IPv4 Type of Service field should be populated in
+   * OnDataAvailableParams.
+   */
+  virtual bool getRecvTos() { return recvTos_; }
+
   /**
    * Set reuse port mode to call bind() on the same address multiple times
    */
@@ -481,16 +487,13 @@ class AsyncUDPSocket : public EventHandler {
   // disable/enable TX zero checksum for UDP over IPv6
   bool setTxZeroChksum6(bool bVal);
 
-  void setTrafficClass(uint8_t tclass);
-
-  void setTos(uint8_t tos);
+  // Set ToS or Traffic Class in the underlying socket
+  // depending on the address family.
+  void setTosOrTrafficClass(uint8_t tosOrTclass);
 
   virtual void applyOptions(
       const SocketOptionMap& options, SocketOptionKey::ApplyPos pos);
 
-  virtual void applyNontrivialOptions(
-      const SocketNontrivialOptionMap& options, SocketOptionKey::ApplyPos pos);
-
   /**
    * Override netops::Dispatcher to be used for netops:: calls.
    *
@@ -545,7 +548,7 @@ class AsyncUDPSocket : public EventHandler {
       struct mmsghdr* msgvec,
       struct iovec* iov,
       size_t iov_count,
-      const int* gso,
+      const WriteOptions* options,
       char* control);
 
   virtual int writeImpl(
@@ -553,11 +556,11 @@ class AsyncUDPSocket : public EventHandler {
       const std::unique_ptr<folly::IOBuf>* bufs,
       size_t count,
       struct mmsghdr* msgvec,
-      const int* gso,
+      const WriteOptions* options,
       char* control);
 
   virtual ssize_t writevImpl(
-      netops::Msgheader* msg, FOLLY_MAYBE_UNUSED int gso);
+      netops::Msgheader* msg, [[maybe_unused]] WriteOptions options);
 
   size_t handleErrMessages() noexcept;
 
@@ -626,8 +629,8 @@ class AsyncUDPSocket : public EventHandler {
   uint32_t zeroCopyBufId_{0};
 
   int getZeroCopyFlags();
-  static bool isZeroCopyMsg(FOLLY_MAYBE_UNUSED const cmsghdr& cmsg);
-  void processZeroCopyMsg(FOLLY_MAYBE_UNUSED const cmsghdr& cmsg);
+  static bool isZeroCopyMsg([[maybe_unused]] const cmsghdr& cmsg);
+  void processZeroCopyMsg([[maybe_unused]] const cmsghdr& cmsg);
   void addZeroCopyBuf(std::unique_ptr<folly::IOBuf>&& buf);
   void releaseZeroCopyBuf(uint32_t id);
 
@@ -637,11 +640,11 @@ class AsyncUDPSocket : public EventHandler {
 
   IOBufFreeFunc ioBufFreeFunc_;
 
-  SocketOptionMap defaultCmsgs_;
-  SocketOptionMap dynamicCmsgs_;
-  SocketOptionMap* cmsgs_{&defaultCmsgs_};
+  SocketCmsgMap defaultCmsgs_;
+  SocketCmsgMap dynamicCmsgs_;
+  SocketCmsgMap* cmsgs_{&defaultCmsgs_};
 
-  SocketNontrivialOptionMap nontrivialCmsgs_;
+  SocketNontrivialCmsgMap nontrivialCmsgs_;
 
   AdditionalCmsgsFunc additionalCmsgsFunc_;
 
