@@ -416,7 +416,9 @@ class NotificationQueue {
    * unmodified.
    */
   bool tryConsume(MessageT& result) {
-    SCOPE_EXIT { syncSignalAndQueue(); };
+    SCOPE_EXIT {
+      syncSignalAndQueue();
+    };
 
     checkPid();
     std::unique_ptr<Node> data;
@@ -424,7 +426,7 @@ class NotificationQueue {
     {
       std::unique_lock<SpinLock> g(spinlock_);
 
-      if (UNLIKELY(queue_.empty())) {
+      if (FOLLY_UNLIKELY(queue_.empty())) {
         return false;
       }
 
@@ -481,7 +483,7 @@ class NotificationQueue {
   }
 
   inline bool checkDraining(bool throws = true) {
-    if (UNLIKELY(draining_ && throws)) {
+    if (FOLLY_UNLIKELY(draining_ && throws)) {
       throw std::runtime_error("queue is draining, cannot add message");
     }
     return draining_;
@@ -666,7 +668,9 @@ void NotificationQueue<MessageT>::Consumer::consumeMessages(
       queue_->syncSignalAndQueue();
     }
   };
-  SCOPE_EXIT { setActive(false, /* shouldLock = */ true); };
+  SCOPE_EXIT {
+    setActive(false, /* shouldLock = */ true);
+  };
   SCOPE_EXIT {
     if (numConsumed != nullptr) {
       *numConsumed = numProcessed;
@@ -685,7 +689,7 @@ void NotificationQueue<MessageT>::Consumer::consumeMessages(
     bool locked = true;
 
     try {
-      if (UNLIKELY(queue_->queue_.empty())) {
+      if (FOLLY_UNLIKELY(queue_->queue_.empty())) {
         // If there is no message, we've reached the end of the queue, return.
         setActive(false);
         queue_->spinlock_.unlock();
@@ -833,7 +837,9 @@ bool NotificationQueue<MessageT>::Consumer::consumeUntilDrained(
 template <typename MessageT>
 template <typename F>
 void NotificationQueue<MessageT>::SimpleConsumer::consume(F&& foreach) {
-  SCOPE_EXIT { queue_.syncSignalAndQueue(); };
+  SCOPE_EXIT {
+    queue_.syncSignalAndQueue();
+  };
 
   queue_.checkPid();
 
@@ -841,7 +847,7 @@ void NotificationQueue<MessageT>::SimpleConsumer::consume(F&& foreach) {
   {
     std::unique_lock<SpinLock> g(queue_.spinlock_);
 
-    if (UNLIKELY(queue_.queue_.empty())) {
+    if (FOLLY_UNLIKELY(queue_.queue_.empty())) {
       return;
     }
 
