@@ -103,7 +103,7 @@ struct Printer {
   }
   void operator()(dynamic const& v, const Context* context) const {
     switch (v.type()) {
-      case dynamic::DOUBLE:
+      case dynamic::DOUBLE: {
         if (!opts_.allow_nan_inf) {
           if (std::isnan(v.asDouble())) {
             throw json::print_error(
@@ -119,10 +119,11 @@ struct Printer {
         toAppend(
             v.asDouble(),
             &out_,
-            opts_.double_mode,
+            opts_.dtoa_mode,
             opts_.double_num_digits,
-            opts_.double_flags);
+            opts_.dtoa_flags);
         break;
+      }
       case dynamic::INT64: {
         auto intval = v.asInt();
         if (opts_.javascript_safe) {
