@@ -14,13 +14,20 @@
  * limitations under the License.
  */
 
+//
+// Docs: https://fburl.com/fbcref_malloc
+//
+
 // Functions to provide smarter use of jemalloc, if jemalloc is being used.
 // http://www.canonware.com/download/jemalloc/jemalloc-latest/doc/jemalloc.html
 
 #pragma once
 
+#include <stdexcept>
+
 #include <folly/Portability.h>
 #include <folly/lang/Bits.h>
+#include <folly/lang/Exception.h>
 #include <folly/portability/Malloc.h>
 
 #ifdef __BMI2__
@@ -80,7 +87,8 @@ class FastStaticBool {
   }
 
  private:
-  FOLLY_NOINLINE FOLLY_COLD FOLLY_EXPORT static bool getSlow() noexcept {
+  [[FOLLY_ATTR_GNU_COLD]] FOLLY_NOINLINE FOLLY_EXPORT static bool
+  getSlow() noexcept {
     static bool rv = [] {
       auto v = Initializer{}();
       flag_.store(v ? 1 : -1, std::memory_order_release);
@@ -89,11 +97,11 @@ class FastStaticBool {
     return rv;
   }
 
-  static std::atomic<char> flag_;
+  static std::atomic<signed char> flag_;
 };
 
 template <class Initializer>
-constinit std::atomic<char> FastStaticBool<Initializer>::flag_;
+constinit std::atomic<signed char> FastStaticBool<Initializer>::flag_{};
 #else // FOLLY_CPLUSPLUS >= 202002L
 // Fallback on native static if std::atomic does not have a constexpr
 // constructor.
@@ -512,4 +520,32 @@ FOLLY_MALLOC_CHECKED_MALLOC FOLLY_NOINLINE inline void* smartRealloc(
   return checkedRealloc(p, newCapacity);
 }
 
+/**
+ * @brief Return value of MALLCTL_ARENAS_ALL defined in jemalloc's header.
+ *
+ * Technically doesn't require that the system is using jemalloc, but jemalloc
+ * header must be included, if it is not, then call to this function will
+ * throw std::logic_error exception.
+ *
+ * Usage example:
+ *
+ * if (folly::usingJEMalloc()) {
+ *   static const std::string kCmd = fmt::format("arena.{}.purge",
+ *       folly::getJEMallocMallctlArenasAll());
+ *   folly::mallctlCall(kCmd.c_str());
+ * }
+ *
+ * @return size_t
+ */
+inline size_t getJEMallocMallctlArenasAll() {
+#if FOLLY_HAS_JEMALLOC_DEFS
+  // Code below will not compile if `MALLCTL_ARENAS_ALL` is not defined, which
+  // might happen if jemalloc renames and/or removes this macro.
+  return MALLCTL_ARENAS_ALL;
+#else
+  throw_exception<std::logic_error>(
+      "getJEMallocMallctlArenasAll: jemalloc header was not included");
+#endif
+}
+
 } // namespace folly
