@@ -106,40 +106,40 @@ class lock_base {
   owner_type state_{};
 
  public:
-  lock_base() = default;
-  lock_base(lock_base&& that) noexcept
+  FOLLY_NODISCARD lock_base() = default;
+  FOLLY_NODISCARD lock_base(lock_base&& that) noexcept
       : mutex_{std::exchange(that.mutex_, nullptr)},
         state_{std::exchange(that.state_, owner_type{})} {}
   template <typename M = mutex_type, if_<!has_state_, M>* = nullptr>
-  lock_base(type_t<M>& mutex, std::adopt_lock_t)
+  FOLLY_NODISCARD lock_base(type_t<M>& mutex, std::adopt_lock_t)
       : mutex_{std::addressof(mutex)}, state_{owner_true_(tag<owner_type>)} {}
   template <typename M = mutex_type, if_<has_state_, M>* = nullptr>
-  lock_base(type_t<M>& mutex, std::adopt_lock_t, owner_type const& state)
+  FOLLY_NODISCARD lock_base(
+      type_t<M>& mutex, std::adopt_lock_t, owner_type const& state)
       : mutex_{std::addressof(mutex)}, state_{state} {
     state_ || (check_fail_<true>(), 0);
   }
-  FOLLY_NODISCARD explicit lock_base(mutex_type& mutex) {
-    mutex_ = std::addressof(mutex);
+  FOLLY_NODISCARD explicit lock_base(mutex_type& mutex)
+      : mutex_{std::addressof(mutex)} {
     lock();
   }
-  lock_base(mutex_type& mutex, std::defer_lock_t) noexcept {
-    mutex_ = std::addressof(mutex);
-  }
-  FOLLY_NODISCARD lock_base(mutex_type& mutex, std::try_to_lock_t) {
-    mutex_ = std::addressof(mutex);
+  lock_base(mutex_type& mutex, std::defer_lock_t) noexcept
+      : mutex_{std::addressof(mutex)} {}
+  FOLLY_NODISCARD lock_base(mutex_type& mutex, std::try_to_lock_t)
+      : mutex_{std::addressof(mutex)} {
     try_lock();
   }
   template <typename Rep, typename Period>
   FOLLY_NODISCARD lock_base(
-      mutex_type& mutex, std::chrono::duration<Rep, Period> const& timeout) {
-    mutex_ = std::addressof(mutex);
+      mutex_type& mutex, std::chrono::duration<Rep, Period> const& timeout)
+      : mutex_{std::addressof(mutex)} {
     try_lock_for(timeout);
   }
   template <typename Clock, typename Duration>
   FOLLY_NODISCARD lock_base(
       mutex_type& mutex,
-      std::chrono::time_point<Clock, Duration> const& deadline) {
-    mutex_ = std::addressof(mutex);
+      std::chrono::time_point<Clock, Duration> const& deadline)
+      : mutex_{std::addressof(mutex)} {
     try_lock_until(deadline);
   }
 
