@@ -41,23 +41,24 @@ DEFINE_int32(numThreads, 8, "Threads to use for concurrency tests.");
 DEFINE_int64(numBMElements, 12 * 1000 * 1000, "Size of maps for benchmarks.");
 
 const double LF = FLAGS_maxLoadFactor / FLAGS_targetLoadFactor;
-const int maxBMElements = int(FLAGS_numBMElements * LF); // hit our target LF.
+const auto maxBMElements =
+    size_t(FLAGS_numBMElements * LF); // hit our target LF.
 
-static int64_t nowInUsec() {
+static uint64_t nowInUsec() {
   timeval tv;
   gettimeofday(&tv, nullptr);
-  return int64_t(tv.tv_sec) * 1000 * 1000 + tv.tv_usec;
+  return uint64_t(tv.tv_sec) * 1000 * 1000 + tv.tv_usec;
 }
 
 TEST(Ahm, BasicStrings) {
-  typedef AtomicHashMap<int64_t, string> AHM;
+  typedef AtomicHashMap<uint64_t, string> AHM;
   AHM myMap(1024);
   EXPECT_TRUE(myMap.begin() == myMap.end());
 
-  for (int i = 0; i < 100; ++i) {
+  for (size_t i = 0; i < 100; ++i) {
     myMap.insert(make_pair(i, folly::to<string>(i)));
   }
-  for (int i = 0; i < 100; ++i) {
+  for (size_t i = 0; i < 100; ++i) {
     EXPECT_EQ(myMap.find(i)->second, folly::to<string>(i));
   }
 
@@ -71,35 +72,35 @@ TEST(Ahm, BasicStrings) {
 }
 
 TEST(Ahm, BasicNoncopyable) {
-  typedef AtomicHashMap<int64_t, std::unique_ptr<int>> AHM;
+  typedef AtomicHashMap<uint64_t, std::unique_ptr<size_t>> AHM;
   AHM myMap(1024);
   EXPECT_TRUE(myMap.begin() == myMap.end());
 
-  for (int i = 0; i < 50; ++i) {
-    myMap.insert(make_pair(i, std::make_unique<int>(i)));
+  for (size_t i = 0; i < 50; ++i) {
+    myMap.insert(make_pair(i, std::make_unique<size_t>(i)));
   }
-  for (int i = 50; i < 100; ++i) {
-    myMap.insert(i, std::make_unique<int>(i));
+  for (size_t i = 50; i < 100; ++i) {
+    myMap.insert(i, std::make_unique<size_t>(i));
   }
-  for (int i = 100; i < 150; ++i) {
-    myMap.emplace(i, new int(i));
+  for (size_t i = 100; i < 150; ++i) {
+    myMap.emplace(i, new size_t(i));
   }
-  for (int i = 150; i < 200; ++i) {
-    myMap.emplace(i, new int(i), std::default_delete<int>());
+  for (size_t i = 150; i < 200; ++i) {
+    myMap.emplace(i, new size_t(i), std::default_delete<size_t>());
   }
-  for (int i = 0; i < 200; ++i) {
+  for (size_t i = 0; i < 200; ++i) {
     EXPECT_EQ(*(myMap.find(i)->second), i);
   }
-  for (int i = 0; i < 200; i += 4) {
+  for (size_t i = 0; i < 200; i += 4) {
     myMap.erase(i);
   }
-  for (int i = 0; i < 200; i += 4) {
+  for (size_t i = 0; i < 200; i += 4) {
     EXPECT_EQ(myMap.find(i), myMap.end());
   }
 }
 
-typedef int32_t KeyT;
-typedef int32_t ValueT;
+typedef uint32_t KeyT;
+typedef uint32_t ValueT;
 
 typedef AtomicHashMap<KeyT, ValueT> AHMapT;
 typedef AHMapT::value_type RecordT;
@@ -112,7 +113,7 @@ static std::unique_ptr<AHMapT> globalAHM;
 static std::unique_ptr<QPAHMapT> globalQPAHM;
 
 // Generate a deterministic value based on an input key
-static int genVal(int key) {
+static size_t genVal(size_t key) {
   return key / 3;
 }
 
@@ -149,7 +150,7 @@ struct HashTraits {
   }
 };
 
-typedef AtomicHashMap<const char*, int64_t, HashTraits, EqTraits> AHMCstrInt;
+typedef AtomicHashMap<const char*, uint64_t, HashTraits, EqTraits> AHMCstrInt;
 AHMCstrInt::Config cstrIntCfg;
 
 static bool legalKey(const char* a) {
@@ -186,7 +187,8 @@ TEST(Ahm, grow) {
   uint64_t numEntries = 10000;
   float sizeFactor = 0.46f;
 
-  std::unique_ptr<AHMapT> m(new AHMapT(int(numEntries * sizeFactor), config));
+  std::unique_ptr<AHMapT> m(
+      new AHMapT(size_t(numEntries * sizeFactor), config));
 
   // load map - make sure we succeed and the index is accurate
   bool success = true;
@@ -218,7 +220,7 @@ TEST(Ahm, grow) {
   // Check findAt
   success = true;
   AHMapT::const_iterator retIt;
-  for (int32_t i = 0; i < int32_t(numEntries); i++) {
+  for (uint32_t i = 0; i < uint32_t(numEntries); i++) {
     retIt = m->find(i);
     retIt = m->findAt(retIt.getIndex());
     success &= (retIt->second == genVal(i));
@@ -243,17 +245,18 @@ TEST(Ahm, grow) {
 }
 
 TEST(Ahm, iterator) {
-  int numEntries = 10000;
+  size_t numEntries = 10000;
   float sizeFactor = .46f;
-  std::unique_ptr<AHMapT> m(new AHMapT(int(numEntries * sizeFactor), config));
+  std::unique_ptr<AHMapT> m(
+      new AHMapT(size_t(numEntries * sizeFactor), config));
 
   // load map - make sure we succeed and the index is accurate
-  for (int i = 0; i < numEntries; i++) {
+  for (size_t i = 0; i < numEntries; i++) {
     m->insert(RecordT(i, genVal(i)));
   }
 
   bool success = true;
-  int count = 0;
+  size_t count = 0;
   FOR_EACH (it, *m) {
     success &= (it->second == genVal(it->first));
     ++count;
@@ -264,15 +267,15 @@ TEST(Ahm, iterator) {
 
 class Counters {
  private:
-  // Note: Unfortunately can't currently put a std::atomic<int64_t> in
+  // Note: Unfortunately can't currently put a std::atomic<uint64_t> in
   // the value in ahm since it doesn't support types that are both non-copy
   // and non-move constructible yet.
-  AtomicHashMap<int64_t, int64_t> ahm;
+  AtomicHashMap<uint64_t, uint64_t> ahm;
 
  public:
   explicit Counters(size_t numCounters) : ahm(numCounters) {}
 
-  void increment(int64_t obj_id) {
+  void increment(uint64_t obj_id) {
     auto ret = ahm.insert(std::make_pair(obj_id, 1));
     if (!ret.second) {
       // obj_id already exists, increment count
@@ -280,7 +283,7 @@ class Counters {
     }
   }
 
-  int64_t getValue(int64_t obj_id) {
+  uint64_t getValue(uint64_t obj_id) {
     auto ret = ahm.find(obj_id);
     return ret != ahm.end() ? ret->second : 0;
   }
@@ -300,11 +303,13 @@ class Counters {
 // If you get an error "terminate called without an active exception", there
 // might be too many threads getting created - decrease numKeys and/or mult.
 TEST(Ahm, counter) {
-  const int numKeys = 10;
-  const int mult = 10;
+  const size_t numKeys = 10;
+  const size_t mult = 10;
   Counters c(numKeys);
-  vector<int64_t> keys;
-  FOR_EACH_RANGE (i, 1, numKeys) { keys.push_back(i); }
+  vector<uint64_t> keys;
+  FOR_EACH_RANGE (i, 1, numKeys) {
+    keys.push_back(i);
+  }
   vector<std::thread> threads;
   for (auto key : keys) {
     FOR_EACH_RANGE (i, 0, key * mult) {
@@ -316,7 +321,7 @@ TEST(Ahm, counter) {
   }
   string str = c.toString();
   for (auto key : keys) {
-    int val = key * mult;
+    size_t val = key * mult;
     EXPECT_EQ(val, c.getValue(key));
     EXPECT_NE(
         string::npos, str.find(folly::to<string>("[", key, ":", val, "]")));
@@ -348,13 +353,13 @@ class Integer {
 TEST(Ahm, mapExceptionSafety) {
   typedef AtomicHashMap<KeyT, Integer> MyMapT;
 
-  int numEntries = 10000;
+  size_t numEntries = 10000;
   float sizeFactor = 0.46f;
-  std::unique_ptr<MyMapT> m(new MyMapT(int(numEntries * sizeFactor)));
+  std::unique_ptr<MyMapT> m(new MyMapT(size_t(numEntries * sizeFactor)));
 
   bool success = true;
-  int count = 0;
-  for (int i = 0; i < numEntries; i++) {
+  size_t count = 0;
+  for (size_t i = 0; i < numEntries; i++) {
     try {
       m->insert(i, Integer(genVal(i)));
       success &= (m->find(i)->second == Integer(genVal(i)));
@@ -373,7 +378,7 @@ TEST(Ahm, basicErase) {
   std::unique_ptr<AHMapT> s(new AHMapT(numEntries, config));
   // Iterate filling up the map and deleting all keys a few times
   // to test more than one subMap.
-  for (int iterations = 0; iterations < 4; ++iterations) {
+  for (size_t iterations = 0; iterations < 4; ++iterations) {
     // Testing insertion of keys
     bool success = true;
     for (size_t i = 0; i < numEntries; ++i) {
@@ -401,20 +406,20 @@ TEST(Ahm, basicErase) {
 
 namespace {
 
-inline KeyT randomizeKey(int key) {
+inline KeyT randomizeKey(uint32_t key) {
   // We deterministically randomize the key to more accurately simulate
   // real-world usage, and to avoid pathalogical performance patterns (e.g.
-  // those related to std::hash<int64_t>()(1) == 1).
+  // those related to std::hash<uint64_t>()(1) == 1).
   //
   // Use a hash function we don't normally use for ints to avoid interactions.
   return folly::hash::jenkins_rev_mix32(key);
 }
 
-int numOpsPerThread = 0;
+size_t numOpsPerThread = 0;
 
 void* insertThread(void* jj) {
-  int64_t j = (int64_t)jj;
-  for (int i = 0; i < numOpsPerThread; ++i) {
+  auto j = (uint64_t)jj;
+  for (size_t i = 0; i < numOpsPerThread; ++i) {
     KeyT key = randomizeKey(i + j * numOpsPerThread);
     globalAHM->insert(key, genVal(key));
   }
@@ -422,8 +427,8 @@ void* insertThread(void* jj) {
 }
 
 void* qpInsertThread(void* jj) {
-  int64_t j = (int64_t)jj;
-  for (int i = 0; i < numOpsPerThread; ++i) {
+  auto j = (uint64_t)jj;
+  for (size_t i = 0; i < numOpsPerThread; ++i) {
     KeyT key = randomizeKey(i + j * numOpsPerThread);
     globalQPAHM->insert(key, genVal(key));
   }
@@ -431,8 +436,8 @@ void* qpInsertThread(void* jj) {
 }
 
 void* insertThreadArr(void* jj) {
-  int64_t j = (int64_t)jj;
-  for (int i = 0; i < numOpsPerThread; ++i) {
+  auto j = (uint64_t)jj;
+  for (size_t i = 0; i < numOpsPerThread; ++i) {
     KeyT key = randomizeKey(i + j * numOpsPerThread);
     globalAHA->insert(std::make_pair(key, genVal(key)));
   }
@@ -440,11 +445,11 @@ void* insertThreadArr(void* jj) {
 }
 
 std::atomic<bool> runThreadsCreatedAllThreads;
-void runThreads(void* (*mainFunc)(void*), int numThreads, void** statuses) {
+void runThreads(void* (*mainFunc)(void*), size_t numThreads, void** statuses) {
   folly::BenchmarkSuspender susp;
   runThreadsCreatedAllThreads.store(false);
   vector<std::thread> threads;
-  for (int64_t j = 0; j < numThreads; j++) {
+  for (uint64_t j = 0; j < numThreads; j++) {
     threads.emplace_back([statuses, mainFunc, j]() {
       auto ret = mainFunc((void*)j);
       if (statuses != nullptr) {
@@ -467,26 +472,26 @@ void runThreads(void* (*mainFunc)(void*)) {
 } // namespace
 
 TEST(Ahm, collisionTest) {
-  const int numInserts = 1000000 / 4;
+  const size_t numInserts = 1000000 / 4;
 
   // Doing the same number on each thread so we collide.
   numOpsPerThread = numInserts;
 
   float sizeFactor = 0.46f;
-  int entrySize = sizeof(KeyT) + sizeof(ValueT);
+  size_t entrySize = sizeof(KeyT) + sizeof(ValueT);
   VLOG(1) << "Testing " << numInserts << " unique " << entrySize
           << " Byte entries replicated in " << FLAGS_numThreads
           << " threads with " << FLAGS_maxLoadFactor * 100.0
           << "% max load factor.";
 
-  globalAHM = std::make_unique<AHMapT>(int(numInserts * sizeFactor), config);
+  globalAHM = std::make_unique<AHMapT>(size_t(numInserts * sizeFactor), config);
 
   size_t sizeInit = globalAHM->capacity();
   VLOG(1) << "  Initial capacity: " << sizeInit;
 
   double start = nowInUsec();
   runThreads([](void*) -> void* { // collisionInsertThread
-    for (int i = 0; i < numOpsPerThread; ++i) {
+    for (size_t i = 0; i < numOpsPerThread; ++i) {
       KeyT key = randomizeKey(i);
       globalAHM->insert(key, genVal(key));
     }
@@ -506,7 +511,7 @@ TEST(Ahm, collisionTest) {
   // check correctness
   EXPECT_EQ(sizeAHM, numInserts);
   bool success = true;
-  for (int i = 0; i < numInserts; ++i) {
+  for (size_t i = 0; i < numInserts; ++i) {
     KeyT key = randomizeKey(i);
     success &= (globalAHM->find(key)->second == genVal(key));
   }
@@ -516,7 +521,7 @@ TEST(Ahm, collisionTest) {
   start = nowInUsec();
   runThreads([](void*) -> void* { // collisionFindThread
     KeyT key(0);
-    for (int i = 0; i < numOpsPerThread; ++i) {
+    for (size_t i = 0; i < numOpsPerThread; ++i) {
       globalAHM->find(key);
     }
     return nullptr;
@@ -530,9 +535,9 @@ TEST(Ahm, collisionTest) {
 
 namespace {
 
-void raceIterateThread(std::atomic<bool>* shouldIterate, int maxSize) {
+void raceIterateThread(std::atomic<bool>* shouldIterate, size_t maxSize) {
   while (shouldIterate->load(std::memory_order_relaxed)) {
-    int count = 0;
+    size_t count = 0;
     AHMapT::iterator it = globalAHM->begin();
     AHMapT::iterator end = globalAHM->end();
     for (; it != end; ++it) {
@@ -545,8 +550,9 @@ void raceIterateThread(std::atomic<bool>* shouldIterate, int maxSize) {
   }
 }
 
-void raceInsertRandomThread(std::atomic<bool>* shouldInsert, int maxInserts) {
-  int i = 0;
+void raceInsertRandomThread(
+    std::atomic<bool>* shouldInsert, size_t maxInserts) {
+  size_t i = 0;
   while (shouldInsert->load(std::memory_order_relaxed) && i++ < maxInserts) {
     KeyT key = rand();
     globalAHM->insert(key, genVal(key));
@@ -558,10 +564,10 @@ void raceInsertRandomThread(std::atomic<bool>* shouldInsert, int maxInserts) {
 // Test for race conditions when inserting and iterating at the same time and
 // creating multiple submaps.
 TEST(Ahm, raceInsertIterateThreadTest) {
-  const int kInsertThreads = 20;
-  const int kIterateThreads = 20;
-  const int kMaxInsertsPerThread = 100000;
-  int raceFinalSizeUpper = kInsertThreads * kMaxInsertsPerThread;
+  const size_t kInsertThreads = 20;
+  const size_t kIterateThreads = 20;
+  const size_t kMaxInsertsPerThread = 100000;
+  size_t raceFinalSizeUpper = kInsertThreads * kMaxInsertsPerThread;
 
   VLOG(1) << "Testing iteration and insertion with " << kInsertThreads
           << " threads inserting and " << kIterateThreads
@@ -589,11 +595,11 @@ TEST(Ahm, raceInsertIterateThreadTest) {
 
 namespace {
 
-const int kTestEraseInsertions = 200000;
+const size_t kTestEraseInsertions = 200000;
 std::atomic<int32_t> insertedLevel;
 
 void* testEraseInsertThread(void*) {
-  for (int i = 0; i < kTestEraseInsertions; ++i) {
+  for (size_t i = 0; i < kTestEraseInsertions; ++i) {
     KeyT key = randomizeKey(i);
     globalAHM->insert(key, genVal(key));
     insertedLevel.store(i, std::memory_order_release);
@@ -603,7 +609,7 @@ void* testEraseInsertThread(void*) {
 }
 
 void* testEraseEraseThread(void*) {
-  for (int i = 0; i < kTestEraseInsertions; ++i) {
+  for (size_t i = 0; i < kTestEraseInsertions; ++i) {
     /*
      * Make sure that we don't get ahead of the insert thread, because
      * part of the condition for this unit test succeeding is that the
@@ -615,8 +621,8 @@ void* testEraseEraseThread(void*) {
      * race causing problems for the test (it's ok for real usage), we
      * lag behind the inserter by more than just element.
      */
-    const int lag = 10;
-    int currentLevel;
+    const size_t lag = 10;
+    size_t currentLevel;
     do {
       currentLevel = insertedLevel.load(std::memory_order_acquire);
       if (currentLevel == kTestEraseInsertions) {
@@ -639,8 +645,8 @@ void* testEraseEraseThread(void*) {
 // Here we have a single thread inserting some values, and several threads
 // racing to delete the values in the order they were inserted.
 TEST(Ahm, threadEraseInsertRace) {
-  const int kInsertThreads = 1;
-  const int kEraseThreads = 10;
+  const size_t kInsertThreads = 1;
+  const size_t kEraseThreads = 10;
 
   VLOG(1) << "Testing insertion and erase with " << kInsertThreads
           << " thread inserting and " << kEraseThreads << " threads erasing.";
@@ -648,7 +654,7 @@ TEST(Ahm, threadEraseInsertRace) {
   globalAHM = std::make_unique<AHMapT>(kTestEraseInsertions / 4, config);
 
   vector<pthread_t> threadIds;
-  for (int64_t j = 0; j < kInsertThreads + kEraseThreads; j++) {
+  for (uint64_t j = 0; j < kInsertThreads + kEraseThreads; j++) {
     pthread_t tid;
     void* (*thread)(void*) =
         (j < kInsertThreads ? testEraseInsertThread : testEraseEraseThread);
@@ -669,7 +675,7 @@ TEST(Ahm, threadEraseInsertRace) {
 }
 
 // Repro for T#483734: Duplicate AHM inserts due to incorrect AHA return value.
-typedef AtomicHashArray<int32_t, int32_t> AHA;
+typedef AtomicHashArray<uint32_t, uint32_t> AHA;
 AHA::Config configRace;
 auto atomicHashArrayInsertRaceArray = AHA::create(2, configRace);
 void* atomicHashArrayInsertRaceThread(void* /* j */) {
@@ -678,7 +684,7 @@ void* atomicHashArrayInsertRaceThread(void* /* j */) {
   while (!runThreadsCreatedAllThreads.load()) {
     ;
   }
-  for (int i = 0; i < 2; i++) {
+  for (size_t i = 0; i < 2; i++) {
     if (arr->insert(RecordT(randomizeKey(i), 0)).first != arr->end()) {
       numInserted++;
     }
@@ -687,14 +693,14 @@ void* atomicHashArrayInsertRaceThread(void* /* j */) {
 }
 TEST(Ahm, atomicHashArrayInsertRace) {
   AHA* arr = atomicHashArrayInsertRaceArray.get();
-  int numIterations = 5000;
-  constexpr int numThreads = 4;
+  size_t numIterations = 5000;
+  constexpr size_t numThreads = 4;
   void* statuses[numThreads];
-  for (int i = 0; i < numIterations; i++) {
+  for (size_t i = 0; i < numIterations; i++) {
     arr->clear();
     runThreads(atomicHashArrayInsertRaceThread, numThreads, statuses);
     EXPECT_GE(arr->size(), 1);
-    for (int j = 0; j < numThreads; j++) {
+    for (size_t j = 0; j < numThreads; j++) {
       EXPECT_EQ(arr->size(), uintptr_t(statuses[j]));
     }
   }
@@ -870,11 +876,11 @@ BENCHMARK(mt_ahm_miss, iters) {
   CHECK_LE(iters, FLAGS_numBMElements);
   numOpsPerThread = iters / FLAGS_numThreads;
   runThreads([](void* jj) -> void* {
-    int64_t j = (int64_t)jj;
+    auto j = (uint64_t)jj;
     while (!runThreadsCreatedAllThreads.load()) {
       ;
     }
-    for (int i = 0; i < numOpsPerThread; ++i) {
+    for (size_t i = 0; i < numOpsPerThread; ++i) {
       KeyT key = i + j * numOpsPerThread * 100;
       folly::doNotOptimizeAway(globalAHM->find(key) == globalAHM->end());
     }
@@ -886,11 +892,11 @@ BENCHMARK(mt_qpahm_miss, iters) {
   CHECK_LE(iters, FLAGS_numBMElements);
   numOpsPerThread = iters / FLAGS_numThreads;
   runThreads([](void* jj) -> void* {
-    int64_t j = (int64_t)jj;
+    auto j = (uint64_t)jj;
     while (!runThreadsCreatedAllThreads.load()) {
       ;
     }
-    for (int i = 0; i < numOpsPerThread; ++i) {
+    for (size_t i = 0; i < numOpsPerThread; ++i) {
       KeyT key = i + j * numOpsPerThread * 100;
       folly::doNotOptimizeAway(globalQPAHM->find(key) == globalQPAHM->end());
     }
@@ -918,11 +924,11 @@ BENCHMARK(mt_ahm_find_insert_mix, iters) {
   CHECK_LE(iters, FLAGS_numBMElements);
   numOpsPerThread = iters / FLAGS_numThreads;
   runThreads([](void* jj) -> void* {
-    int64_t j = (int64_t)jj;
+    uint64_t j = (uint64_t)jj;
     while (!runThreadsCreatedAllThreads.load()) {
       ;
     }
-    for (int i = 0; i < numOpsPerThread; ++i) {
+    for (size_t i = 0; i < numOpsPerThread; ++i) {
       if (i % 128) { // ~1% insert mix
         KeyT key = randomizeKey(i + j * numOpsPerThread);
         folly::doNotOptimizeAway(globalAHM->find(key)->second);
@@ -939,11 +945,11 @@ BENCHMARK(mt_qpahm_find_insert_mix, iters) {
   CHECK_LE(iters, FLAGS_numBMElements);
   numOpsPerThread = iters / FLAGS_numThreads;
   runThreads([](void* jj) -> void* {
-    int64_t j = (int64_t)jj;
+    auto j = (uint64_t)jj;
     while (!runThreadsCreatedAllThreads.load()) {
       ;
     }
-    for (int i = 0; i < numOpsPerThread; ++i) {
+    for (size_t i = 0; i < numOpsPerThread; ++i) {
       if (i % 128) { // ~1% insert mix
         KeyT key = randomizeKey(i + j * numOpsPerThread);
         folly::doNotOptimizeAway(globalQPAHM->find(key)->second);
@@ -960,11 +966,11 @@ BENCHMARK(mt_aha_find, iters) {
   CHECK_LE(iters, FLAGS_numBMElements);
   numOpsPerThread = iters / FLAGS_numThreads;
   runThreads([](void* jj) -> void* {
-    int64_t j = (int64_t)jj;
+    auto j = (uint64_t)jj;
     while (!runThreadsCreatedAllThreads.load()) {
       ;
     }
-    for (int i = 0; i < numOpsPerThread; ++i) {
+    for (size_t i = 0; i < numOpsPerThread; ++i) {
       KeyT key = randomizeKey(i + j * numOpsPerThread);
       folly::doNotOptimizeAway(globalAHA->find(key)->second);
     }
@@ -976,11 +982,11 @@ BENCHMARK(mt_ahm_find, iters) {
   CHECK_LE(iters, FLAGS_numBMElements);
   numOpsPerThread = iters / FLAGS_numThreads;
   runThreads([](void* jj) -> void* {
-    int64_t j = (int64_t)jj;
+    auto j = (uint64_t)jj;
     while (!runThreadsCreatedAllThreads.load()) {
       ;
     }
-    for (int i = 0; i < numOpsPerThread; ++i) {
+    for (size_t i = 0; i < numOpsPerThread; ++i) {
       KeyT key = randomizeKey(i + j * numOpsPerThread);
       folly::doNotOptimizeAway(globalAHM->find(key)->second);
     }
@@ -992,11 +998,11 @@ BENCHMARK(mt_qpahm_find, iters) {
   CHECK_LE(iters, FLAGS_numBMElements);
   numOpsPerThread = iters / FLAGS_numThreads;
   runThreads([](void* jj) -> void* {
-    int64_t j = (int64_t)jj;
+    auto j = (uint64_t)jj;
     while (!runThreadsCreatedAllThreads.load()) {
       ;
     }
-    for (int i = 0; i < numOpsPerThread; ++i) {
+    for (size_t i = 0; i < numOpsPerThread; ++i) {
       KeyT key = randomizeKey(i + j * numOpsPerThread);
       folly::doNotOptimizeAway(globalQPAHM->find(key)->second);
     }
@@ -1015,7 +1021,7 @@ BENCHMARK(st_baseline_modulus_and_random, iters) {
 
 BENCHMARK(mt_ahm_insert, iters) {
   BENCHMARK_SUSPEND {
-    globalAHM = std::make_unique<AHMapT>(int(iters * LF), config);
+    globalAHM = std::make_unique<AHMapT>(size_t(iters * LF), config);
     numOpsPerThread = iters / FLAGS_numThreads;
   }
   runThreads(insertThread);
@@ -1023,7 +1029,7 @@ BENCHMARK(mt_ahm_insert, iters) {
 
 BENCHMARK(mt_qpahm_insert, iters) {
   BENCHMARK_SUSPEND {
-    globalQPAHM = std::make_unique<QPAHMapT>(int(iters * LF), qpConfig);
+    globalQPAHM = std::make_unique<QPAHMapT>(size_t(iters * LF), qpConfig);
     numOpsPerThread = iters / FLAGS_numThreads;
   }
   runThreads(qpInsertThread);
@@ -1031,7 +1037,7 @@ BENCHMARK(mt_qpahm_insert, iters) {
 
 BENCHMARK(st_ahm_insert, iters) {
   folly::BenchmarkSuspender susp;
-  std::unique_ptr<AHMapT> ahm(new AHMapT(int(iters * LF), config));
+  std::unique_ptr<AHMapT> ahm(new AHMapT(size_t(iters * LF), config));
   susp.dismiss();
 
   for (size_t i = 0; i < iters; i++) {
@@ -1042,7 +1048,7 @@ BENCHMARK(st_ahm_insert, iters) {
 
 BENCHMARK(st_qpahm_insert, iters) {
   folly::BenchmarkSuspender susp;
-  std::unique_ptr<QPAHMapT> ahm(new QPAHMapT(int(iters * LF), qpConfig));
+  std::unique_ptr<QPAHMapT> ahm(new QPAHMapT(size_t(iters * LF), qpConfig));
   susp.dismiss();
 
   for (size_t i = 0; i < iters; i++) {
@@ -1055,12 +1061,12 @@ void benchmarkSetup() {
   config.maxLoadFactor = FLAGS_maxLoadFactor;
   qpConfig.maxLoadFactor = FLAGS_maxLoadFactor;
   configRace.maxLoadFactor = 0.5;
-  int numCores = sysconf(_SC_NPROCESSORS_ONLN);
+  size_t numCores = sysconf(_SC_NPROCESSORS_ONLN);
   loadGlobalAha();
   loadGlobalAhm();
   loadGlobalQPAhm();
-  string numIters =
-      folly::to<string>(std::min(1000000, int(FLAGS_numBMElements)));
+  string numIters = folly::to<string>(
+      std::min(1000000UL, (unsigned long)FLAGS_numBMElements));
 
   gflags::SetCommandLineOptionWithMode(
       "bm_max_iters", numIters.c_str(), gflags::SET_FLAG_IF_DEFAULT);
@@ -1090,6 +1096,11 @@ int main(int argc, char** argv) {
 }
 
 /*
+FUTURE READER: This benchmark is quite likely buggy!  Take these numbers
+with scoopfuls of salt.  For example, looking at `mt_ahm_miss` while
+increasing --bm_min_iters in 10x steps from 10,000 to 1,000,000 we see:
+62ns, 6.4ns, 760ps.  This suggests it is not measuring what it thinks.
+
 loading global AHA with 8 threads...
   took 487 ms (40 ns/insert).
 loading global AHM with 8 threads...
