@@ -198,7 +198,7 @@ TEST(UnorderedInsertMap, valueMutation) {
 
 // This test is too expensive to run automatically.  On my dev server it
 // takes about 10 minutes for dbg build, 2 for opt.
-TEST(AtomicUnorderedInsertMap, DISABLEDMegaMap) {
+TEST(AtomicUnorderedInsertMap, DISABLED_MegaMap) {
   size_t capacity = 2000000000;
   AtomicUnorderedInsertMap64<size_t, size_t> big(capacity);
   for (size_t i = 0; i < capacity * 2; i += 2) {
@@ -238,7 +238,9 @@ BENCHMARK(lookup_int_int_hit, iters) {
     EXPECT_EQ(iter->second, k + 1);
   }
 
-  BENCHMARK_SUSPEND { ptr.reset(nullptr); }
+  BENCHMARK_SUSPEND {
+    ptr.reset(nullptr);
+  }
 }
 
 struct PairHash {
@@ -302,7 +304,9 @@ void contendedRW(
     thr.join();
   }
 
-  BENCHMARK_SUSPEND { ptr.reset(nullptr); }
+  BENCHMARK_SUSPEND {
+    ptr.reset(nullptr);
+  }
 }
 
 // clang-format off
