@@ -30,8 +30,8 @@
 #include <folly/String.h>
 #include <folly/detail/FileUtilDetail.h>
 #include <folly/detail/FileUtilVectorDetail.h>
-#include <folly/experimental/TestUtil.h>
 #include <folly/portability/GTest.h>
+#include <folly/testing/TestUtil.h>
 
 namespace folly {
 namespace test {
