@@ -23,9 +23,9 @@
 #include <folly/Benchmark.h>
 #include <folly/FBVector.h>
 #include <folly/Utility.h>
-#include <folly/dynamic.h>
 #include <folly/init/Init.h>
-#include <folly/json.h>
+#include <folly/json/dynamic.h>
+#include <folly/json/json.h>
 
 FOLLY_GNU_DISABLE_WARNING("-Wdeprecated-declarations")
 
