@@ -1259,7 +1259,7 @@ TEST(IPAddress, getMacAddressFromLinkLocal) {
   EXPECT_EQ("f4:52:14:c5:74:d8", ip6.getMacAddressFromLinkLocal()->toString());
 }
 
-TEST(IPAddress, getMacAddressFromLinkLocal_Negative) {
+TEST(IPAddress, getMacAddressFromLinkLocalNegative) {
   IPAddressV6 no_link_local_ip6("2803:6082:a2:4447::1");
   EXPECT_FALSE(no_link_local_ip6.getMacAddressFromLinkLocal().has_value());
   no_link_local_ip6 = IPAddressV6("fe80::f652:14ff:ccc5:74d8");
@@ -1279,7 +1279,7 @@ TEST(IPAddress, getMacAddressFromEUI64) {
   EXPECT_EQ("48:57:dd:04:56:43", ip6.getMacAddressFromEUI64()->toString());
 }
 
-TEST(IPAddress, getMacAddressFromEUI64_Negative) {
+TEST(IPAddress, getMacAddressFromEUI64Negative) {
   IPAddressV6 not_eui64_ip6("2401:db00:3020:51dc:face:0000:009a:0000");
   EXPECT_FALSE(not_eui64_ip6.getMacAddressFromEUI64().has_value());
 }
